@@ -13,7 +13,7 @@
 ##############################################################################
 """Session implementation
 
-$Id: session.py 87351 2008-06-12 21:02:43Z gary $
+$Id: session.py 90600 2008-08-29 21:32:29Z fdrake $
 """
 from cStringIO import StringIO
 import time, string, random, thread
@@ -461,7 +461,7 @@ class SessionData(persistent.Persistent, IterableUserDict):
     be removed in a later release (see the comments in the code below).
 
     First, create an instance of SessionData and remove a protected attribute
-    _lastAcessTime from it to make it more like the legacy SessionData.  The
+    _lastAccessTime from it to make it more like the legacy SessionData.  The
     subsequent attempt to get lastAccessTime will return a 0, because the
     lastAccessTime is not there and the dictionary returns the default value
     zero supplied to its get() method.
